@@ -1,14 +1,14 @@
-mod html_escape;
+mod color;
+mod emoji;
+mod html;
 mod table_align;
 mod text_align;
 mod text_escape;
+mod urls;
 
-pub use html_escape::*;
-pub use table_align::*;
-pub use text_align::*;
-pub use text_escape::*;
-
+pub use self::{color::*, emoji::*, html::*, table_align::*, text_align::*, text_escape::*};
 
+/// capitalize first letter
 pub fn capitalize_first_letter(text: impl AsRef<str>) -> String {
     let text = text.as_ref();
     let mut c = text.chars();
@@ -16,4 +16,4 @@ pub fn capitalize_first_letter(text: impl AsRef<str>) -> String {
         None => String::new(),
         Some(f) => f.to_uppercase().collect::<String>() + c.as_str(),
     }
-}
\ No newline at end of file
+}
